Use `uv run pytest` to run tests
Use `uv` to manage dependencies

Use `ruff` to lint and reformat the code. Always lint and format at the end of all tasks. If the this step makes changes, rerun tests, and rerun `ruff`.

Don't bother with backward compatibility for API, just build the best solution.

Follow preexisting conventions in the project.

Use English.
